<!--
 Copyright 2021 D4n13l3k00.
 SPDX-License-Identifier: 	AGPL-3.0-or-later
-->

# Anipics

## Simple module for getting anime pictures

### Installation:

`pip install anipics`

### Usage:

Example of usage [here](/example.py)